@@ -13,6 +13,8 @@ pub struct Settings {
     pub preview: bool,
     pub preview_with_bat: bool,
     pub preview_fallback_exa: bool,
+    pub show_git_branch: bool,
+    pub git_branch_separator: String,
 }
 
 fn is_program_in_path(program: &str) -> bool {
@@ -36,6 +38,8 @@ impl Settings {
         s.set_default("preview", true)?;
         s.set_default("preview_with_bat", is_program_in_path("bat"))?;
         s.set_default("preview_fallback_exa", is_program_in_path("exa"))?;
+        s.set_default("show_git_branch", true)?;
+        s.set_default("git_branch_separator", "■")?;
 
         let home = home_dir();
         if home.is_none() {
